@@ -223,7 +223,6 @@ class BertAttention(nn.Module):
         
         return attention_output, attention_metrix
 
-
 class BertIntermediate(nn.Module):
     def __init__(self, config):
         super().__init__()
@@ -248,7 +247,6 @@ class BertOutput(nn.Module):
         hidden_states = self.LayerNorm(hidden_states + input_tensor)
         return hidden_states
 
-
 class BertLayer(nn.Module):
     def __init__(self, config):
         super().__init__()
@@ -267,7 +265,6 @@ class BertLayer(nn.Module):
         layer_output = self.output(intermediate_output, attention_output)
         return layer_output, attention_matrix
 
-
 class BertEncoder(nn.Module):
     def __init__(self, config):
         super().__init__()
@@ -476,3 +473,12 @@ class BertModel(BertPreTrainedModel):
             # 如果不用输出所有encoder层
             encoder_layers = encoder_layers[-1]
         return encoder_layers, pooled_output
+
+
+if __name__ == "__main__":
+    t1 = (torch.rand(2, 10) * 10).long()
+    config = BertConfig(vocab_size=256, hidden_size=768)
+    embed = BertEmbeddings(config)
+    out = embed(t1)
+    print(out.shape)
+    
\ No newline at end of file
